@@ -1,3 +1,8 @@
+import glob, os, shutil, os, sys
+sys.path.append("synesthesia")
+
+print(os.getcwd())
+
 from PyQt5.QtCore import Qt
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import *
@@ -5,7 +10,7 @@ from wsl import *
 from image_helper import *
 from PIL.ImageQt import ImageQt
 from essentia_helper import *
-import glob, os, shutil, os, sys
+
 
 
 class Window(QWidget):
@@ -255,10 +260,9 @@ def main_func():
     app.exec()
 
 def pmain_func():
-    os.chdir('synesthesia')
     print("jah test47")
     main_func()
-
+    # os.chdir('synesthesia')
 
 if __name__ == '__main__':
     main_func()
